@@ -1,13 +1,11 @@
 #!/bin/sh -e
 
 VERSION=$2
-TAR=../modello_$VERSION.orig.tar.gz
+TAR=../modello1.4_$VERSION.orig.tar.gz
 DIR=modello-$VERSION
 TAG=modello-$2
 
-mkdir -p $DIR
-tar --strip=1 -xvf $3 -C $DIR
-rm $3
+svn export https://svn.codehaus.org/modello/tags/$TAG $DIR
 rm -rf $DIR/modello-maven-plugin
 rm -rf $DIR/modello-test
 tar -c -z -f $TAR $DIR
